%define oname		squirrel3

%define major		0
%define libname		%mklibname %{name} %{major}
%define develname	%mklibname %{name} -d

%define ver %(echo %{version} |tr '.' '_')

Name:		squirrel
Version:	3.2
Release:	%mkrel 1
Summary:	The squirrel language
License:	zlib
Group:		Development/Other
URL:		http://squirrel-lang.org
Source0:	https://download.sourceforge.net/squirrel/%{name}_%{ver}_stable.tar.gz
# Missing from src tarball
Source1:	https://raw.githubusercontent.com/albertodemichelis/squirrel/v%{version}/squirrel-config.cmake.in
#
# Security patches
# P100 -> ...
#
Patch100:	CVE-2022-30292.patch
BuildRequires:	cmake

%description
Squirrel is a light weight programming language featuring higher-order
functions,classes/inheritance, delegation,tail recursion,generators,cooperative
threads,exception handling, reference counting and garbage collection on
demand. C-like syntax.

%package -n %{libname}
Summary:	Libraries for %{name}
Group:		Development/Other

%description -n %{libname}
Shared library files for %name.

%package -n %{develname}
Summary:	Header files and static libraries from %{name}
Group:		Development/Other
Requires:	%{libname} = %{version}-%{release}
Provides:	lib%{name}-devel = %{version}-%{release}
Provides:	%{name}-devel = %{version}-%{release}

%description -n %{develname}
Libraries and includes files for developing programs based on %name.


%prep
%setup -qn %{oname}
%autopatch -p1

# fix file permissions
find . -type f -exec chmod a-x {} \;

# fix EOL + preserve timestamps
for f in README HISTORY COPYRIGHT
do
    perl -pi -e 's/\015$//' $f
done

# install files missing from source tarball
if ! [ -x %(basename %{SOURCE1}) ]; then
  install -Dpm 644 %{SOURCE1} .
fi

%build
%cmake -DDISABLE_STATIC=ON \
  -DCMAKE_INSTALL_INCLUDEDIR:PATH=%{_includedir}/%{name}

%cmake_build

%install
%cmake_install

#correct wrong file end of line encoding
perl -pi -e 's/\015$//' %{buildroot}/%{_includedir}/*

# Add pkgconfig file
mkdir -p %{buildroot}%{_libdir}/pkgconfig
cat >%{buildroot}%{_libdir}/pkgconfig/squirrel.pc <<EOF
prefix=%{_prefix}
exec_prefix=%{_prefix}
libdir=%{_libdir}
includedir=%{_includedir}/squirrel

Name: %{name}
Description: squirrel library
Version: %{version}

Requires:
Libs: -L\${libdir} -lsquirrel -lsqstdlib
Cflags: -I\${includedir}
EOF

%files
%doc README HISTORY COPYRIGHT COMPILE
%{_bindir}/sq

%files -n %{libname}
%{_libdir}/libsqstdlib.so.%{major}{,.*}
%{_libdir}/libsquirrel.so.%{major}{,.*}

%files -n %{develname}
%{_includedir}/%{name}/
%{_libdir}/libsqstdlib.so
%{_libdir}/libsquirrel.so
%{_libdir}/pkgconfig/*
%{_libdir}/cmake/%{name}/


%changelog
* Mon Aug 15 2022 pol4n <pol4n> 3.2-1.mga8
+ Revision: 1878044
- New version 3.2 and CVE-2022-30292
+ neoclust <neoclust>
- Add P100: Fixes CVE-2022-30292 (mga#30430)

* Thu Feb 20 2020 umeabot <umeabot> 3.1-2.mga8
+ Revision: 1547372
- Mageia 8 Mass Rebuild

* Sat Feb 08 2020 daviddavid <daviddavid> 3.1-1.mga8
+ Revision: 1488044
- new version: 3.1
- switch to cmake build system
+ wally <wally>
- replace deprecated %%configure2_5x
- replace deprecated %%makeinstall_std

* Sun Sep 23 2018 umeabot <umeabot> 2.2.5-9.mga7
+ Revision: 1301162
- Mageia 7 Mass Rebuild

* Fri Feb 05 2016 umeabot <umeabot> 2.2.5-8.mga6
+ Revision: 938432
- Mageia 6 Mass Rebuild

* Wed Oct 15 2014 umeabot <umeabot> 2.2.5-7.mga5
+ Revision: 748543
- Second Mageia 5 Mass Rebuild

* Tue Sep 16 2014 umeabot <umeabot> 2.2.5-6.mga5
+ Revision: 689311
- Mageia 5 Mass Rebuild

* Fri Oct 18 2013 umeabot <umeabot> 2.2.5-5.mga4
+ Revision: 518515
- Mageia 4 Mass Rebuild

* Mon Jan 14 2013 umeabot <umeabot> 2.2.5-4.mga3
+ Revision: 382602
- Mass Rebuild - https://wiki.mageia.org/en/Feature:Mageia3MassRebuild

* Thu Jan 10 2013 cjw <cjw> 2.2.5-3.mga3
+ Revision: 344554
- patch2: fix build with automake 1.13

* Sun Jul 29 2012 fwang <fwang> 2.2.5-2.mga3
+ Revision: 275757
- split out shared libs

* Mon Feb 27 2012 kamil <kamil> 2.2.5-1.mga2
+ Revision: 215542
- new version 2.2.5
- sync .spec with Fedora
  o add patches:
  * P0 autotools.patch
  * P1 mem.patch
  o disable static library
- update license (it's zlib not GPL)

* Fri Apr 01 2011 dams <dams> 2.2.4-1.mga1
+ Revision: 79375
- imported package squirrel


* Sat Jan 02 2010 Frederik Himpe <fhimpe@mandriva.org> 2.2.4-1mdv2010.1
+ Revision: 485099
- update to new version 2.2.4

* Mon Sep 14 2009 Tomasz Pawel Gajc <tpg@mandriva.org> 2.2.3-1mdv2010.0
+ Revision: 440751
- update to new version 2.2.3

* Thu Sep 03 2009 Christophe Fergeau <cfergeau@mandriva.com> 2.2.2-2mdv2010.0
+ Revision: 427214
- rebuild

* Mon Oct 20 2008 Tomasz Pawel Gajc <tpg@mandriva.org> 2.2.2-1mdv2009.1
+ Revision: 295753
- update to new version 2.2.2

* Wed Jun 18 2008 Thierry Vignaud <tvignaud@mandriva.com> 2.2-2mdv2009.0
+ Revision: 225474
- rebuild

* Mon Feb 18 2008 Tomasz Pawel Gajc <tpg@mandriva.org> 2.2-1mdv2008.1
+ Revision: 171205
- new version

  + Olivier Blin <oblin@mandriva.com>
    - restore BuildRoot

* Fri Dec 21 2007 Tomasz Pawel Gajc <tpg@mandriva.org> 2.1.2-2mdv2008.1
+ Revision: 136102
- obsolete older devel package

* Thu Dec 20 2007 Tomasz Pawel Gajc <tpg@mandriva.org> 2.1.2-1mdv2008.1
+ Revision: 135793
- drop patch 0
- fix building on x86_64
- new version
- fix docs
- set proper bits on files
- new devel library policy
- update url
- spec file clean
- new version

  + Thierry Vignaud <tvignaud@mandriva.com>
    - kill re-definition of %%buildroot on Pixel's request


* Sun Jan 28 2007 Götz Waschk <waschk@mandriva.org> 2_0_5-4mdv2007.0
+ Revision: 114513
- Import squirrel

* Sun Jan 28 2007 Götz Waschk <waschk@mandriva.org> 2_0_5-4mdv2007.1
- unpack patch

* Sat Feb 04 2006 Sebastien Savarin <plouf@mandriva.org> 2_0_5-4mdk
- Fix build on x86_64 big thanks to couriousous

* Thu Feb 02 2006 Sebastien Savarin <plouf@mandriva.org> 2_0_5-3mdk
- prevent conflict with ispel

* Sun Dec 25 2005 Sebastien Savarin <plouf@mandriva.org> 2_0_5-2mdk
- Fix Group

* Sun Dec 18 2005 Sebastien Savarin <plouf@mandriva.org> 2_0_5-1mdk
- First Mandriva Linux release

